summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--cscript2
-rw-r--r--src/lib/dcpomatic_socket.cc8
-rw-r--r--src/wx/supporters.cc1
-rw-r--r--src/wx/verify_dcp_result_panel.cc2
m---------test/data0
-rw-r--r--test/render_subtitles_test.cc7
-rw-r--r--test/test.cc7
-rw-r--r--test/test.h1
8 files changed, 24 insertions, 4 deletions
diff --git a/cscript b/cscript
index 87a090b9d..e43d205bb 100644
--- a/cscript
+++ b/cscript
@@ -529,7 +529,7 @@ option_defaults = { "gui": True, "variant": None }
def build_tests(target):
# Currently we only build tests on macOS, Windows, some Ubuntu versions and Arch
return (
- (target.platform == 'linux' and target.distro == 'ubuntu' and target.version in ['18.04', '22.04', '24.04', '25.10']) or
+ (target.platform == 'linux' and target.distro == 'ubuntu' and target.version in ['18.04', '22.04', '24.04', '26.04']) or
(target.platform == 'linux' and target.distro == 'arch') or
(target.platform == 'osx') or
(target.platform == 'windows')
diff --git a/src/lib/dcpomatic_socket.cc b/src/lib/dcpomatic_socket.cc
index d3bfbc309..876fa47d3 100644
--- a/src/lib/dcpomatic_socket.cc
+++ b/src/lib/dcpomatic_socket.cc
@@ -50,7 +50,11 @@ Socket::Socket (int timeout)
void
Socket::check ()
{
+#if BOOST_VERSION >= 108700
if (_deadline.expiry() <= std::chrono::system_clock::now()) {
+#else
+ if (_deadline.expires_at() <= std::chrono::system_clock::now()) {
+#endif
_socket.close();
_deadline.expires_at(std::chrono::time_point<std::chrono::system_clock>::max());
}
@@ -321,7 +325,11 @@ Socket::set_send_buffer_size (int size)
void
Socket::set_deadline_from_now(int seconds)
{
+#if BOOST_VERSION >= 108700
_deadline.expires_after(std::chrono::seconds(seconds));
+#else
+ _deadline.expires_from_now(std::chrono::seconds(seconds));
+#endif
}
void
diff --git a/src/wx/supporters.cc b/src/wx/supporters.cc
index 18951fa4f..dff4f9a7c 100644
--- a/src/wx/supporters.cc
+++ b/src/wx/supporters.cc
@@ -1491,6 +1491,7 @@ supported_by.Add (wxT ("Tilman Vatteroth"));
supported_by.Add (wxT ("Jos Vecht"));
supported_by.Add (wxT ("Christian Vennefrohne"));
supported_by.Add (wxT ("Jaap Verseput"));
+supported_by.Add (wxT ("Dan Viafore"));
supported_by.Add (wxT ("Videoworld"));
supported_by.Add (wxT ("Robert Vidić"));
supported_by.Add (wxT ("Burg Kino Vienna"));
diff --git a/src/wx/verify_dcp_result_panel.cc b/src/wx/verify_dcp_result_panel.cc
index 2de26d172..aa5da95c6 100644
--- a/src/wx/verify_dcp_result_panel.cc
+++ b/src/wx/verify_dcp_result_panel.cc
@@ -345,7 +345,7 @@ VerifyDCPResultPanel::add(shared_ptr<const VerifyDCPJob> job, bool many)
);
break;
case dcp::VerificationNote::Code::EXTERNAL_ASSET:
- add(i.second, _("This DCP refers to at the asset %asset_id in another DCP (and perhaps others), so it is a \"version file\" (VF)"));
+ add(i.second, _("This DCP refers to the asset %asset_id in another DCP (and perhaps others), so it is a \"version file\" (VF)"));
break;
case dcp::VerificationNote::Code::THREED_ASSET_MARKED_AS_TWOD:
add(i.second, _("The asset %f is 3D but its MXF is marked as 2D."));
diff --git a/test/test.cc b/test/test.cc
index 641ee4085..27b00b9d3 100644
--- a/test/test.cc
+++ b/test/test.cc
@@ -473,6 +473,13 @@ check_image (boost::filesystem::path ref, boost::filesystem::path check, double
}
+bool
+check_image_and_report(boost::filesystem::path ref, boost::filesystem::path check, double threshold)
+{
+ return rms_error(ref, check) < threshold;
+}
+
+
void
check_file (boost::filesystem::path ref, boost::filesystem::path check)
{
diff --git a/test/test.h b/test/test.h
index 172edcf71..cd40c7872 100644
--- a/test/test.h
+++ b/test/test.h
@@ -69,6 +69,7 @@ extern bool mxf_atmos_files_same (boost::filesystem::path ref, boost::filesystem
extern void check_xml(boost::filesystem::path, boost::filesystem::path, std::list<Glib::ustring>);
extern void check_ffmpeg(boost::filesystem::path, boost::filesystem::path, float audio_tolerance);
extern void check_image(boost::filesystem::path ref, boost::filesystem::path check, double threshold = 4);
+extern bool check_image_and_report(boost::filesystem::path ref, boost::filesystem::path check, double threshold = 4);
extern boost::filesystem::path test_film_dir (std::string);
extern void write_image (std::shared_ptr<const Image> image, boost::filesystem::path file);
boost::filesystem::path dcp_file (std::shared_ptr<const Film> film, std::string prefix);
diff --git a/test/data b/test/data
-Subproject fe6973d73602cff710f5ea2396a47074b21686d
+Subproject 2576ae9426703165d81eb44776d515a54eda587
diff --git a/test/render_subtitles_test.cc b/test/render_subtitles_test.cc
index 4e87abde0..4fc98cb56 100644
--- a/test/render_subtitles_test.cc
+++ b/test/render_subtitles_test.cc
@@ -176,8 +176,11 @@ BOOST_AUTO_TEST_CASE(render_text_with_newline_test)
#elif defined(DCPOMATIC_WINDOWS)
check_image("test/data/windows/render_text_with_newline_test.png", "build/test/render_text_with_newline_test.png");
#elif PANGO_VERSION_CHECK(1, 57, 0)
- /* This pango version is the one on Arch, which renders slightly differently */
- check_image("test/data/arch/render_text_with_newline_test.png", "build/test/render_text_with_newline_test.png");
+ /* This pango version is the one on Arch and Ubuntu 26.04, both of which render slightly differently */
+ BOOST_REQUIRE(
+ check_image_and_report("test/data/arch/render_text_with_newline_test.png", "build/test/render_text_with_newline_test.png")
+ || check_image_and_report("test/data/ubuntu-26.04/render_text_with_newline_test.png", "build/test/render_text_with_newline_test.png")
+ );
#elif PANGO_VERSION_CHECK(1, 52, 1)
/* This pango version is the one on Ubuntu 24.04, which renders slightly differently */
check_image("test/data/ubuntu-24.04/render_text_with_newline_test.png", "build/test/render_text_with_newline_test.png");